@@ -15,23 +15,26 @@
 
 import ctypes
 import os
+import socket
 import sys
 
 from oslo_log import log as logging
 
 from os_win._i18n import _, _LE
+from os_win import _utils
 from os_win import exceptions
 from os_win.utils import baseutils
 from os_win.utils import win32utils
 
 if sys.platform == 'win32':
     kernel32 = ctypes.windll.kernel32
-    import wmi
 
 LOG = logging.getLogger(__name__)
 
 
 class SMBUtils(baseutils.BaseUtils):
+    _loopback_share_map = {}
+
     def __init__(self):
         self._win32_utils = win32utils.Win32Utils()
         self._smb_conn = self._get_wmi_conn(r"root\Microsoft\Windows\SMB")
@@ -57,7 +60,7 @@ class SMBUtils(baseutils.BaseUtils):
             self._smb_conn.Msft_SmbMapping.Create(RemotePath=share_path,
                                                   UserName=username,
                                                   Password=password)
-        except wmi.x_wmi as exc:
+        except exceptions.x_wmi as exc:
             err_msg = (_(
                 'Unable to mount SMBFS share: %(share_path)s '
                 'WMI exception: %(wmi_exc)s') % {'share_path': share_path,
@@ -77,7 +80,7 @@ class SMBUtils(baseutils.BaseUtils):
                 mapping.Remove(Force=force)
             except AttributeError:
                 pass
-            except wmi.x_wmi:
+            except exceptions.x_wmi:
                 # If this fails, a 'Generic Failure' exception is raised.
                 # This happens even if we unforcefully unmount an in-use
                 # share, for which reason we'll simply ignore it in this
@@ -112,3 +115,31 @@ class SMBUtils(baseutils.BaseUtils):
                 return 0, 0
             else:
                 raise exc
+
+    def get_smb_share_path(self, share_name):
+        shares = self._smb_conn.Msft_SmbShare(Name=share_name)
+        share_path = shares[0].Path if shares else None
+        if not shares:
+            LOG.debug("Could not find any local share named %s.", share_name)
+        return share_path
+
+    def is_local_share(self, share_path):
+        # In case of Scale-Out File Servers, we'll get the Distributed Node
+        # Name of the share. We have to check whether this resolves to a
+        # local ip, which would happen in a hyper converged scenario.
+        #
+        # In this case, mounting the share is not supported and we have to
+        # use the local share path.
+        if share_path in self._loopback_share_map:
+            return self._loopback_share_map[share_path]
+
+        addr = share_path.lstrip('\\').split('\\', 1)[0]
+
+        local_ips = _utils.get_ips(socket.gethostname())
+        local_ips += _utils.get_ips('localhost')
+
+        dest_ips = _utils.get_ips(addr)
+        is_local = bool(set(local_ips).intersection(set(dest_ips)))
+
+        self._loopback_share_map[share_path] = is_local
+        return is_local
